interface BaseNode {
    type: Node['type'];
}
export declare type Node = Document | TemplateNode | Element | ImportNode | ElementAtrrbute | FragmentNode | DataBindingNode | ImportSJSNode;
export declare type Element = ElementNode | ForElementNode | TextNode | IfElementNode | ElseIfElementNode | ElseElementNode | UseTemplateNode | SlotNode | UseSlotNode | IncludeNode | BlockNode | CommentNode | SlotScopeNode;
export declare type ElementAtrrbute = RefAttributeNode | AttributeNode | EventAttributeNode | StyleAttributeNode | ClassAttributeNode | NamedSlotAttributeNode | UnSupportAttribute;
export interface Document extends BaseNode {
    type: 'Document';
    fragment: FragmentNode;
    imports: Array<ImportNode | ImportSJSNode>;
    templates: Array<TemplateNode>;
}
export declare function document(imports: Array<ImportNode>, templates: Array<TemplateNode>, fragment: FragmentNode): Document;
export interface DataBindingNode extends BaseNode {
    type: 'DataBindingNode';
    express: string;
    readonly hasBinding: boolean;
    readonly bindingExpression: string;
    readonly bindingVars: Set<string>;
    getExpressionAst(options?: any): any;
    getExpressionAstForText(): any;
}
export declare function dataBindingNode(express: string): DataBindingNode;
export interface FragmentNode extends BaseNode {
    type: 'FragmentNode';
    body: Array<Element>;
}
export declare function fragmentNode(body: Array<Element>): FragmentNode;
export declare function isFragmentNode(node: BaseNode): boolean;
export interface ImportNode extends BaseNode {
    type: 'ImportNode';
    src?: string;
    name?: string;
    from?: string;
}
export declare function importNode(src?: string, name?: string, from?: string): ImportNode;
export interface ImportSJSNode extends BaseNode {
    type: 'ImportSJSNode';
    name?: string;
    from?: string;
    src?: string;
}
export declare function importSJSNode(name?: string, from?: string): ImportSJSNode;
export interface IncludeNode extends BaseNode {
    type: 'IncludeNode';
    src: string;
    name?: string;
}
export declare function includeNode(src: string): IncludeNode;
/**
 * 元素节点
 */
export interface ElementNode extends BaseNode {
    type: 'ElementNode';
    name: string;
    attributes: Array<ElementAtrrbute>;
    children: Array<Element>;
    nodeId: string;
}
export declare function elementNode(name: string, nodeId: string, attributes?: Array<ElementAtrrbute>, children?: Array<Element>): ElementNode;
export declare function isElementNode(node: BaseNode): boolean;
export interface BlockNode extends BaseNode {
    type: 'BlockNode';
    children: Array<Element>;
    attributes: Array<ElementAtrrbute>;
    name?: string;
}
export declare function blockNode(children?: Array<Element>, attributes?: Array<ElementAtrrbute>): BlockNode;
/**
 * for节点
 */
export interface ForElementNode extends BaseNode {
    type: 'ForElementNode';
    name?: string;
    expresion: DataBindingNode;
    element: Element;
    item?: string;
    index?: string;
}
export declare function forElementNode(expresion: DataBindingNode, element: Element): ForElementNode;
export interface IfElementNode extends BaseNode {
    type: 'IfElementNode';
    expresion: DataBindingNode;
    ifElement: Element;
    elseIfElements: ElseIfElementNode[];
    elseElement?: ElseElementNode;
    name?: string;
}
export declare function ifElementNode(expresion: DataBindingNode, ifElement: Element): IfElementNode;
export interface ElseIfElementNode extends BaseNode {
    type: 'ElseIfElementNode';
    expresion: DataBindingNode;
    element: Element;
    name?: string;
}
export declare function elseIfElementNode(expresion: DataBindingNode, element: Element): ElseIfElementNode;
export interface ElseElementNode extends BaseNode {
    type: 'ElseElementNode';
    element: Element;
    name?: string;
}
export declare function elseElementNode(element: Element): ElseElementNode;
/**
 * 使用模板的节点
 */
export interface UseTemplateNode extends BaseNode {
    type: 'UseTemplateNode';
    templateName: DataBindingNode;
    dataExpression: DataBindingNode;
    name?: string;
}
export declare function useTemplateNode(templateName: DataBindingNode, dataExpression: DataBindingNode): UseTemplateNode;
export declare function isUseTemplateNode(node: BaseNode): boolean;
/**
 * 元素属性
 */
export interface AttributeNode extends BaseNode {
    type: 'AttributeNode';
    name: string;
    value: DataBindingNode;
}
export declare function attributeNode(name: string, value: DataBindingNode): AttributeNode;
export interface UnSupportAttribute extends BaseNode {
    type: 'UnSupportAttributeNode';
    name: string;
    value: DataBindingNode;
}
export declare function makeUnSupportAttributeNode(name: string, value: DataBindingNode): UnSupportAttribute;
/**
 * 事件属性节点
 */
export interface EventAttributeNode extends BaseNode {
    type: 'EventAttributeNode';
    name: string;
    value: DataBindingNode;
    isCatch: boolean;
}
export declare function eventAttributeNode(name: string, value: DataBindingNode, isCatch?: boolean): EventAttributeNode;
/**
 * ref 引用的属性节点
 */
export interface RefAttributeNode extends BaseNode {
    type: 'RefAttributeNode';
    value: DataBindingNode;
}
export declare function refAttributeNode(value: DataBindingNode): RefAttributeNode;
export interface StyleAttributeNode extends BaseNode {
    type: 'StyleAttributeNode';
    value: DataBindingNode;
}
export declare function styleAttributeNode(value: DataBindingNode): StyleAttributeNode;
export interface ClassAttributeNode extends BaseNode {
    type: 'ClassAttributeNode';
    value: DataBindingNode;
}
export declare function classAttributeNode(value: DataBindingNode): ClassAttributeNode;
/**
 * 文本节点
 */
export interface TextNode extends BaseNode {
    type: 'TextNode';
    text: DataBindingNode;
    name?: string;
}
export declare function textNode(text: DataBindingNode): TextNode;
/**
 * 模板节点
 */
export interface TemplateNode extends BaseNode {
    type: 'TemplateNode';
    name: string;
    fragment: FragmentNode;
}
export declare function templateNode(name: string, fragment: FragmentNode): TemplateNode;
export declare function isTemplateNode(node: BaseNode): boolean;
/**
 * 定义slot
 */
export interface SlotNode extends BaseNode {
    type: 'SlotNode';
    name?: DataBindingNode;
    attributes: Array<ElementAtrrbute>;
    children: Array<Element>;
}
export declare function slotNode(children: Array<Element>, attributes: Array<ElementAtrrbute>, name?: DataBindingNode): SlotNode;
export interface NamedSlotAttributeNode extends BaseNode {
    type: 'NamedSlotAttributeNode';
    name: DataBindingNode;
}
export declare function namedSlotAttributeNode(name: DataBindingNode): NamedSlotAttributeNode;
/**
 * 使用slot
 */
export interface UseSlotNode extends BaseNode {
    type: 'UseSlotNode';
    name: string;
    element: Element;
}
export interface SlotScopeNode extends BaseNode {
    type: 'SlotScopeNode';
    value: string;
    slot?: string;
    element: Element;
    name?: string;
}
export declare function slotScopeNode(value: string, element: Element, slot?: string): SlotScopeNode;
/**
 * 注释节点
 */
export interface CommentNode extends BaseNode {
    type: 'CommentNode';
    comment: string;
    name?: string;
}
export declare function commentNode(comment: string): CommentNode;
export {};
