"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Plugin = exports.templateSingleTagClosingType = exports.targetDescription = exports.target = exports.resolveMainFields = exports.projectConfigFiles = exports.globalObject = exports.defaultOutputDir = exports.defaultConditionalFileExt = exports.templateSingleTagNames = exports.templateProcessor = exports.templateDirectives = exports.supportGlobalComponents = exports.sjsTagName = exports.sjsSrcAttrName = exports.sjsModuleAttrName = exports.isSupportSjsContent = exports.getRuntimeFiles = exports.fileType = exports.compileScriptTarget = exports.compileModuleKind = void 0;
const plugin_compiler_alipay_1 = require("@morjs/plugin-compiler-alipay");
const constants_1 = require("./constants");
const atomicFileGeneratePlugin_1 = require("./plugins/atomicFileGeneratePlugin");
const bundleOptimizationPlugin_1 = require("./plugins/bundleOptimizationPlugin");
const commonConfigPlugin_1 = require("./plugins/commonConfigPlugin");
const configCompatiblePlugin_1 = require("./plugins/configCompatiblePlugin");
const devServerPlugin_1 = require("./plugins/devServerPlugin");
const emitIntermediateAssetsPlugin_1 = require("./plugins/emitIntermediateAssetsPlugin");
const extractOrInjectCssPlugin_1 = require("./plugins/extractOrInjectCssPlugin");
const generateJSXEntryPlugin_1 = require("./plugins/generateJSXEntryPlugin");
const htmlSupportPlugin_1 = require("./plugins/htmlSupportPlugin");
const scriptCompatiblePlugin_1 = require("./plugins/scriptCompatiblePlugin");
const sjsCompatiblePlugin_1 = require("./plugins/sjsCompatiblePlugin");
const templateCompatiblePlugin_1 = require("./plugins/templateCompatiblePlugin");
var plugin_compiler_alipay_2 = require("@morjs/plugin-compiler-alipay");
Object.defineProperty(exports, "compileModuleKind", { enumerable: true, get: function () { return plugin_compiler_alipay_2.compileModuleKind; } });
Object.defineProperty(exports, "compileScriptTarget", { enumerable: true, get: function () { return plugin_compiler_alipay_2.compileScriptTarget; } });
Object.defineProperty(exports, "fileType", { enumerable: true, get: function () { return plugin_compiler_alipay_2.fileType; } });
Object.defineProperty(exports, "getRuntimeFiles", { enumerable: true, get: function () { return plugin_compiler_alipay_2.getRuntimeFiles; } });
Object.defineProperty(exports, "isSupportSjsContent", { enumerable: true, get: function () { return plugin_compiler_alipay_2.isSupportSjsContent; } });
Object.defineProperty(exports, "sjsModuleAttrName", { enumerable: true, get: function () { return plugin_compiler_alipay_2.sjsModuleAttrName; } });
Object.defineProperty(exports, "sjsSrcAttrName", { enumerable: true, get: function () { return plugin_compiler_alipay_2.sjsSrcAttrName; } });
Object.defineProperty(exports, "sjsTagName", { enumerable: true, get: function () { return plugin_compiler_alipay_2.sjsTagName; } });
Object.defineProperty(exports, "supportGlobalComponents", { enumerable: true, get: function () { return plugin_compiler_alipay_2.supportGlobalComponents; } });
Object.defineProperty(exports, "templateDirectives", { enumerable: true, get: function () { return plugin_compiler_alipay_2.templateDirectives; } });
Object.defineProperty(exports, "templateProcessor", { enumerable: true, get: function () { return plugin_compiler_alipay_2.templateProcessor; } });
Object.defineProperty(exports, "templateSingleTagNames", { enumerable: true, get: function () { return plugin_compiler_alipay_2.templateSingleTagNames; } });
var constants_2 = require("./constants");
Object.defineProperty(exports, "defaultConditionalFileExt", { enumerable: true, get: function () { return constants_2.defaultConditionalFileExt; } });
Object.defineProperty(exports, "defaultOutputDir", { enumerable: true, get: function () { return constants_2.defaultOutputDir; } });
Object.defineProperty(exports, "globalObject", { enumerable: true, get: function () { return constants_2.globalObject; } });
Object.defineProperty(exports, "projectConfigFiles", { enumerable: true, get: function () { return constants_2.projectConfigFiles; } });
Object.defineProperty(exports, "resolveMainFields", { enumerable: true, get: function () { return constants_2.resolveMainFields; } });
Object.defineProperty(exports, "target", { enumerable: true, get: function () { return constants_2.target; } });
Object.defineProperty(exports, "targetDescription", { enumerable: true, get: function () { return constants_2.targetDescription; } });
Object.defineProperty(exports, "templateSingleTagClosingType", { enumerable: true, get: function () { return constants_2.templateSingleTagClosingType; } });
// 将当前 target 添加为 支付宝类似小程序
// 以复用 支付宝相关的转换逻辑
(0, plugin_compiler_alipay_1.addSimilarTarget)(constants_1.target);
const WrapperMap = new WeakMap();
const EntryBuilderMap = new WeakMap();
/**
 * web 编译插件
 * - 支持微信支付宝小程序 DSL 编译为 web 项目
 */
class WebCompilerPlugin {
    constructor() {
        this.name = 'MorWebCompilerPlugin';
    }
    apply(runner) {
        new emitIntermediateAssetsPlugin_1.EmitIntermediateAssetsPlugin().apply(runner);
        runner.hooks.webpackWrapper.tap(this.name, function (wrapper) {
            WrapperMap.set(runner, wrapper);
        });
        runner.hooks.entryBuilder.tap(this.name, function (entryBuilder) {
            EntryBuilderMap.set(runner, entryBuilder);
        });
        runner.hooks.registerUserConfig.tap(this.name, function (schema) {
            return schema.merge(constants_1.UserConfigSchema);
        });
        runner.hooks.userConfigValidated.tapPromise({
            name: this.name,
            stage: 100
        }, async () => {
            const { compileMode, target } = (runner.userConfig || {});
            if (target !== constants_1.target)
                return;
            const wrapper = WrapperMap.get(runner);
            const entryBuilder = EntryBuilderMap.get(runner);
            new commonConfigPlugin_1.CommonConfigPlugin(wrapper, entryBuilder).apply(runner);
            new sjsCompatiblePlugin_1.SjsCompatiblePlugin().apply(runner);
            new templateCompatiblePlugin_1.TemplateCompatiblePlugin(entryBuilder).apply(runner);
            new configCompatiblePlugin_1.ConfigCompatiblePlugin(entryBuilder).apply(runner);
            new scriptCompatiblePlugin_1.ScriptCompatiblePlugin().apply(runner);
            // bundle 模式适配
            if (compileMode === 'bundle') {
                new extractOrInjectCssPlugin_1.ExtractOrInjectCssPlugin(wrapper).apply(runner);
                new generateJSXEntryPlugin_1.GenerateJSXEntryPlugin(wrapper).apply(runner);
                new htmlSupportPlugin_1.HtmlSupportPlugin(wrapper).apply(runner);
                await new devServerPlugin_1.DevServerPlugin(wrapper).apply(runner);
                new bundleOptimizationPlugin_1.BundleOptimizationPlugin(wrapper).apply(runner);
            }
            // 非 bundle 模式适配
            else {
                new atomicFileGeneratePlugin_1.AtomicFileGeneratePlugin().apply(runner);
            }
        });
    }
}
exports.Plugin = WebCompilerPlugin;
//# sourceMappingURL=index.js.map