import { EntryBuilderHelpers, EntryItem, webpack, WebpackUserConfig } from '@morjs/utils';
import { BuildOptions } from '../compiler/core/option';
export interface WebLoaderOptions {
    /**
     * 全局组件名称的配置关系
     */
    globalComponentsConfig: object;
    /**
     * 全局自定义组件
     */
    usingComponents?: object;
    /**
     * rpx 方案的 root value。默认是32。也就是 16*2
     */
    rpxRootValue?: number;
    /**
     * 是否使用 rpx2rem 插件对 rpx 单位进行转换
     */
    needRpx?: boolean;
    /**
     * 默认编译出来的样式会以 rem 为单位，
     * 配合 runtime 层提供的 setRootFontSizeForRem 方法可以实现移动端的响应式。
     * 如果不想将样式单位编译成 rem 可以配置该对象，
     * 对象中包含一个参数 ratio 用于指定 rpx 2 px 的转换比例。
     * 如 ratio 为 1， 那么 1rpx = 1px， 如果配置 ratio 为 2， 那么 1rpx = 0.5px
     */
    usePx?: {
        ratio?: number;
    };
    /**
     * 是否需要样式隔离，如果开启该功能，在编译时会给样式加上唯一 hash 值，用于多页面解决样式冲突问题
     */
    styleScope?: boolean;
    /**
     *  平台 小写。默认 h5
     */
    platform?: string;
    /**
     * 文件条件编译后缀
     */
    conditionalCompileFileExt?: string[];
    /**
     * entry builder helpers
     */
    entryBuilder: EntryBuilderHelpers;
    /**
     * 用户配置
     */
    userConfig: WebpackUserConfig & {
        compileType: string;
        [k: string]: any;
    };
}
declare type LoaderCompileMethod = (options: BuildOptions) => Promise<string>;
export declare class LoaderBuilder {
    static process(loader: webpack.LoaderContext<WebLoaderOptions>, fn: LoaderCompileMethod): Promise<void>;
    private loader;
    private loaderOptions;
    private entryBuilder;
    private userConfig;
    /**
     * 是否为组件编译模式
     */
    private isAtomicMode;
    /**
     * 关联文件
     */
    relevantPaths: Pick<BuildOptions, 'scriptFilePath' | 'templateFilePath' | 'styleFilePath' | 'configFilePath'>;
    /**
     * 获取关联的 entries
     */
    relevantEntries: {
        scriptEntry?: EntryItem;
        templateEntry?: EntryItem;
        styleEntry?: EntryItem;
        configEntry?: EntryItem;
    };
    private callback;
    constructor(loader: webpack.LoaderContext<WebLoaderOptions>);
    private getResourceName;
    generateOptions(): Promise<BuildOptions>;
    private getRelevants;
    private getRelativePath;
    private loadModule;
    compile(fn: LoaderCompileMethod): Promise<void>;
    private loadRelatedConfig;
    private getModuleJsonData;
    private getAppConfigFilePath;
    private loadAppConfig;
}
export {};
