"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BundleOptimizationPlugin = void 0;
const utils_1 = require("@morjs/utils");
/**
 * 默认编译优化配置
 */
class BundleOptimizationPlugin {
    constructor(wrapper) {
        this.wrapper = wrapper;
        this.name = 'MorWebBundleOptimizationPlugin';
    }
    apply(runner) {
        var _a, _b;
        this.removeMiniFileGenerator();
        this.setupDefaultOptimization((_a = runner === null || runner === void 0 ? void 0 : runner.userConfig) === null || _a === void 0 ? void 0 : _a.globalNameSuffix);
        this.supportSjsExtensionAlias((_b = runner === null || runner === void 0 ? void 0 : runner.userConfig) === null || _b === void 0 ? void 0 : _b.sourceType);
    }
    // 不生成小程序相关产物
    removeMiniFileGenerator() {
        const chain = this.wrapper.chain;
        chain.module.rule('style').delete('type').delete('generator').end();
        chain.module.rule('sass').delete('type').delete('generator').end();
        chain.module.rule('less').delete('type').delete('generator').end();
        chain.module.rule('config').delete('type').delete('generator').end();
        chain.module.rule('template').delete('type').delete('generator').end();
        chain.module.rule('sjs').delete('type').delete('generator').end();
    }
    // 微信 DSL 转 Web 在 bundle 模式下
    // 会将 wxml 中的 wxs 以及 wxs 自身对 wxs 引用转换为 sjs 文件引用
    // 这里通过 extension 来解决
    supportSjsExtensionAlias(sourceType) {
        if (sourceType === utils_1.SourceTypes.wechat) {
            const chain = this.wrapper.chain;
            const wxsExtensions = chain.resolve.extensionAlias.get('.wxs') || [];
            const sjsExtensions = chain.resolve.extensionAlias.get('.sjs') || [];
            chain.resolve.extensionAlias.set('.wxs', [
                ...wxsExtensions,
                '.wxs',
                '.sjs'
            ]);
            chain.resolve.extensionAlias.set('.sjs', [
                ...sjsExtensions,
                '.sjs',
                '.wxs'
            ]);
        }
    }
    /**
     * 设置默认的打包优化
     */
    setupDefaultOptimization(globalNameSuffix) {
        // 默认优化
        this.wrapper.chain.optimization.splitChunks({
            chunks: 'all',
            maxAsyncRequests: 6,
            maxInitialRequests: 6,
            minSize: 30000,
            cacheGroups: {
                // react 运行时
                react: {
                    name: 'react',
                    test: /[\\/]react|react-dom[\\/]/,
                    priority: 4
                },
                // runtime-web 运行时
                web: {
                    name: (0, utils_1.MOR_RUNTIME_WEB_FILE)(globalNameSuffix),
                    test: /(@morjs[\\/]|@ali[\\/]openmor-)runtime-web/,
                    priority: 3
                },
                // 其他 node_modules
                vendors: {
                    name: (0, utils_1.MOR_VENDOR_FILE)(globalNameSuffix),
                    test: /\/(node_modules|npm_components|mock)\//,
                    priority: 2
                }
            }
        });
    }
}
exports.BundleOptimizationPlugin = BundleOptimizationPlugin;
//# sourceMappingURL=bundleOptimizationPlugin.js.map